@@ -152,7 +152,7 @@ def import_annotations(
         raise ValueError(f"file_paths must be a list of 'Path' or 'str'. Current value: {file_paths}")
 
     print("Fetching remote class list...")
-    team_classes: Optional[List[Dict[str, Any]]] = dataset.fetch_remote_classes(True)
+    team_classes: List[Dict[str, Any]] = dataset.fetch_remote_classes(True)
     if not team_classes:
         raise ValueError("Unable to fetch remote class list.")
 
@@ -229,7 +229,7 @@ def import_annotations(
 
     # Refetch classes to update mappings
     if local_classes_not_in_team or local_classes_not_in_dataset:
-        maybe_remote_classes: Optional[List[Dict[str, Any]]] = dataset.fetch_remote_classes()
+        maybe_remote_classes: List[Dict[str, Any]] = dataset.fetch_remote_classes()
         if not maybe_remote_classes:
             raise ValueError("Unable to fetch remote classes.")
 
@@ -273,17 +273,19 @@ def _handle_subs(
         if sub.annotation_type == "text":
             data["text"] = {"text": sub.data}
         elif sub.annotation_type == "attributes":
-            data["attributes"] = {
-                "attributes": [
-                    attributes[annotation_class_id][attr]
-                    for attr in sub.data
-                    if annotation_class_id in attributes and attr in attributes[annotation_class_id]
-                ]
-            }
+            attributes_with_key = []
+            for attr in sub.data:
+                if annotation_class_id in attributes and attr in attributes[annotation_class_id]:
+                    attributes_with_key.append(attributes[annotation_class_id][attr])
+                else:
+                    print(f"The attribute '{attr}' for class '{annotation.annotation_class.name}' was not imported.")
+
+            data["attributes"] = {"attributes": attributes_with_key}
         elif sub.annotation_type == "instance_id":
             data["instance_id"] = {"value": sub.data}
         else:
             data[sub.annotation_type] = sub.data
+
     return data
 
 
@@ -327,6 +329,7 @@ def _import_annotations(
     if append:
         payload["overwrite"] = "false"
 
-    res = client.post(f"/dataset_items/{id}/import", payload=payload)
-    if res.get("status_code") != 200:
-        print(f"warning, failed to upload annotation to {id}", res)
+    try:
+        client.import_annotation(id, payload=payload)
+    except:
+        print(f"warning, failed to upload annotation to item {id}. Annotations: {payload}")
