@@ -1,23 +1,32 @@
 import json
 import platform
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, Dict, List, Optional, Set, Union
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    Dict,
+    Iterable,
+    Iterator,
+    List,
+    Optional,
+    Set,
+    Union,
+)
 
 import numpy as np
-from rich.progress import track
+from rich.progress import ProgressType, track
 from upolygon import draw_polygon
 
 import darwin.datatypes as dt
 from darwin.config import Config
 from darwin.exceptions import OutdatedDarwinJSONFormat, UnsupportedFileType
-from darwin.types import PathLike
 
 if TYPE_CHECKING:
     from darwin.client import Client
 
 
 SUPPORTED_IMAGE_EXTENSIONS = [".png", ".jpeg", ".jpg", ".jfif", ".tif", ".tiff", ".bmp", ".svs"]
-SUPPORTED_VIDEO_EXTENSIONS = [".avi", ".bpm", ".dcm", ".mov", ".mp4"]
+SUPPORTED_VIDEO_EXTENSIONS = [".avi", ".bpm", ".dcm", ".mov", ".mp4", ".pdf"]
 SUPPORTED_EXTENSIONS = SUPPORTED_IMAGE_EXTENSIONS + SUPPORTED_VIDEO_EXTENSIONS
 
 
@@ -58,7 +67,7 @@ def is_project_dir(project_path: Path) -> bool:
     return (project_path / "releases").exists() and (project_path / "images").exists()
 
 
-def get_progress_bar(array: List, description: Optional[str] = None):
+def get_progress_bar(array: List, description: Optional[str] = None) -> Iterable["ProgressType"]:
     if description:
         return track(array, description=description)
     return track(array)
@@ -89,15 +98,17 @@ def prompt(msg: str, default: Optional[str] = None) -> str:
     return result
 
 
-def find_files(files: List[PathLike], *, files_to_exclude: List[PathLike] = [], recursive: bool = True) -> List[Path]:
+def find_files(
+    files: List[dt.PathLike], *, files_to_exclude: List[dt.PathLike] = [], recursive: bool = True
+) -> List[Path]:
     """Retrieve a list of all files belonging to supported extensions. The exploration can be made
     recursive and a list of files can be excluded if desired.
 
     Parameters
     ----------
-    files: List[PathLike]
+    files: List[dt.PathLike]
         List of files that will be filtered with the supported file extensions and returned.
-    files_to_exclude : List[PathLike]
+    files_to_exclude : List[dt.PathLike]
         List of files to exclude from the search.
     recursive : bool
         Flag for recursive search.
@@ -156,15 +167,18 @@ def persist_client_configuration(
         config_path = Path.home() / ".darwin" / "config.yaml"
         config_path.parent.mkdir(exist_ok=True)
 
-    team_config = client.config.get_default_team()
-    config = Config(config_path)
-    config.set_team(team=team_config["slug"], api_key=team_config["api_key"], datasets_dir=team_config["datasets_dir"])
+    team_config: Optional[dt.Team] = client.config.get_default_team()
+    if not team_config:
+        raise ValueError("Unable to get default team.")
+
+    config: Config = Config(config_path)
+    config.set_team(team=team_config.slug, api_key=team_config.api_key, datasets_dir=team_config.datasets_dir)
     config.set_global(api_endpoint=client.url, base_url=client.base_url, default_team=default_team)
 
     return config
 
 
-def get_local_filename(metadata: dict):
+def get_local_filename(metadata: Dict[str, Any]) -> str:
     return metadata["filename"]
 
 
@@ -178,7 +192,7 @@ def parse_darwin_json(path: Path, count: Optional[int]) -> Optional[dt.Annotatio
     path : Path
         Path to the file to parse.
     count : Optional[int]
-        Optional count parameter. Used only if the Annotation's image sequence is None.
+        Optional count parameter. Used only if the 's image sequence is None.
 
     Returns
     -------
@@ -215,7 +229,7 @@ def parse_darwin_image(path: Path, data: Dict[str, Any], count: Optional[int]) -
     data : Dict[str, Any]
         The decoded JSON file in Python format.
     count : Optional[int]
-        Optional count parameter. Used only if the Annotation's image sequence is None.
+        Optional count parameter. Used only if the 's image sequence is None.
 
     Returns
     -------
@@ -282,9 +296,9 @@ def parse_darwin_video(path: Path, data: Dict[str, Any], count: Optional[int]) -
     )
 
 
-def parse_darwin_annotation(annotation: Dict[str, Any]):
-    name = annotation["name"]
-    main_annotation = None
+def parse_darwin_annotation(annotation: Dict[str, Any]) -> Optional[dt.Annotation]:
+    name: str = annotation["name"]
+    main_annotation: Optional[dt.Annotation] = None
     if "polygon" in annotation:
         bounding_box = annotation.get("bounding_box")
         if "additional_paths" in annotation["polygon"]:
@@ -331,10 +345,10 @@ def parse_darwin_annotation(annotation: Dict[str, Any]):
     return main_annotation
 
 
-def parse_darwin_video_annotation(annotation: dict):
+def parse_darwin_video_annotation(annotation: dict) -> dt.VideoAnnotation:
     name = annotation["name"]
     frame_annotations = {}
-    keyframes = {}
+    keyframes: Dict[int, bool] = {}
     for f, frame in annotation["frames"].items():
         frame_annotations[int(f)] = parse_darwin_annotation({**frame, **{"name": name}})
         keyframes[int(f)] = frame.get("keyframe", False)
@@ -344,15 +358,20 @@ def parse_darwin_video_annotation(annotation: dict):
     )
 
 
-def split_video_annotation(annotation):
+def split_video_annotation(annotation: dt.AnnotationFile) -> List[dt.AnnotationFile]:
     if not annotation.is_video:
         raise AttributeError("this is not a video annotation")
 
+    if not annotation.frame_urls:
+        raise AttributeError("This Annotation has no frame urls")
+
     frame_annotations = []
     for i, frame_url in enumerate(annotation.frame_urls):
-        annotations = [a.frames[i] for a in annotation.annotations if i in a.frames]
-        annotation_classes = set([annotation.annotation_class for annotation in annotations])
-        filename = f"{Path(annotation.filename).stem}/{i:07d}.png"
+        annotations = [
+            a.frames[i] for a in annotation.annotations if isinstance(a, dt.VideoAnnotation) and i in a.frames
+        ]
+        annotation_classes: Set[dt.AnnotationClass] = set([annotation.annotation_class for annotation in annotations])
+        filename: str = f"{Path(annotation.filename).stem}/{i:07d}.png"
 
         frame_annotations.append(
             dt.AnnotationFile(
@@ -371,13 +390,13 @@ def split_video_annotation(annotation):
     return frame_annotations
 
 
-def ispolygon(annotation):
+def ispolygon(annotation: dt.AnnotationClass) -> bool:
     return annotation.annotation_type in ["polygon", "complex_polygon"]
 
 
 def convert_polygons_to_sequences(
-    polygons: List, height: Optional[int] = None, width: Optional[int] = None, rounding: bool = True
-) -> List:
+    polygons: Any, height: Optional[int] = None, width: Optional[int] = None, rounding: bool = True,
+) -> List[List[Union[int, float]]]:
     """
     Converts a list of polygons, encoded as a list of dictionaries of into a list of nd.arrays
     of coordinates.
@@ -402,15 +421,18 @@ def convert_polygons_to_sequences(
         raise ValueError("No polygons provided")
     # If there is a single polygon composing the instance then this is
     # transformed to polygons = [[{x: x1, y:y1}, ..., {x: xn, y:yn}]]
-    if isinstance(polygons[0], dict):
-        polygons = [polygons]
+    list_polygons: List[dt.Polygon] = []
+    if isinstance(polygons[0], list):
+        list_polygons = polygons
+    else:
+        list_polygons = [polygons]
 
-    if not isinstance(polygons[0], list) or not isinstance(polygons[0][0], dict):
+    if not isinstance(list_polygons[0], list) or not isinstance(list_polygons[0][0], dict):
         raise ValueError("Unknown input format")
 
-    sequences = []
-    for polygon in polygons:
-        path = []
+    sequences: List[List[Union[int, float]]] = []
+    for polygon in list_polygons:
+        path: List[Union[int, float]] = []
         for point in polygon:
             # Clip coordinates to the image size
             x = max(min(point["x"], width - 1) if width else point["x"], 0)
@@ -425,7 +447,9 @@ def convert_polygons_to_sequences(
     return sequences
 
 
-def convert_sequences_to_polygons(sequences: List, height: Optional[int] = None, width: Optional[int] = None) -> Dict:
+def convert_sequences_to_polygons(
+    sequences: List[Union[List[int], List[float]]], height: Optional[int] = None, width: Optional[int] = None
+) -> Dict[str, List[dt.Polygon]]:
     """
     Converts a list of polygons, encoded as a list of dictionaries of into a list of nd.arrays
     of coordinates.
@@ -470,7 +494,7 @@ def convert_sequences_to_polygons(sequences: List, height: Optional[int] = None,
     return {"path": polygons}
 
 
-def convert_xyxy_to_bounding_box(box: List) -> dict:
+def convert_xyxy_to_bounding_box(box: List[Union[int, float]]) -> dt.BoundingBox:
     """
     Converts a list of xy coordinates representing a bounding box into a dictionary
 
@@ -484,7 +508,7 @@ def convert_xyxy_to_bounding_box(box: List) -> dict:
     bounding_box: dict
         Bounding box in the format {x: x1, y: y1, h: height, w: width}
     """
-    if not isinstance(box[0], (int, float)):
+    if not isinstance(box[0], float) and not isinstance(box[0], int):
         raise ValueError("Unknown input format")
 
     x1, y1, x2, y2 = box
@@ -493,7 +517,7 @@ def convert_xyxy_to_bounding_box(box: List) -> dict:
     return {"x": x1, "y": y1, "w": width, "h": height}
 
 
-def convert_bounding_box_to_xyxy(box: dict) -> list:
+def convert_bounding_box_to_xyxy(box: dt.BoundingBox) -> List[float]:
     """
     Converts dictionary representing a bounding box into a list of xy coordinates
 
@@ -534,7 +558,7 @@ def convert_polygons_to_mask(polygons: List, height: int, width: int, value: Opt
     return mask
 
 
-def chunk(items, size):
+def chunk(items: List[Any], size: int) -> Iterator[Any]:
     for i in range(0, len(items), size):
         yield items[i : i + size]
 
